@@ -35,7 +35,7 @@ under the same terms as Perl itself.
 
 =cut
 
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 use Mouse;
 use Carp;
@@ -134,7 +134,7 @@ sub make_object
     croak "no argument passed to new()";
   }
 
-  if ($object->{is_relationshiptype}) {
+  if ($object->{is_relationshiptype} && $object->{name}) {
     $object->{name} =~ s/ /_/g;
   }
 
@@ -283,7 +283,13 @@ sub to_string
     my @ret_lines = ();
 
     if (ref $value) {
-      for my $single_value (@$value) {
+      my @values;
+      if ($field_conf{$name}->{type} eq 'SINGLE_HASH') {
+        push @values, $value;
+      } else {
+        @values = @$value;
+      }
+      for my $single_value (@values) {
         my $to_string_proc = $field_conf{$name}->{to_string};
         my $value_as_string;
         if (defined $to_string_proc) {
